export const instanceName = '#name';
export const instanceHostname = '#hostname';
export const instanceUsername = '#username';
export const instancePassword = '#password';
export const instanceFingerprint = '#fingerprint';
export const addButtonModal =
  '#pf-modal-part-0 > footer > div > div > button.pf-c-button.pf-m-primary';
export const vmwareMenu = '.pf-c-tabs__link';
export enum dataLabel {
  name = '[data-label=Name]',
  endpoint = '[data-label=Endpoint]',
  clusters = '[data-label=Clusters]',
  hosts = '[data-label=Hosts]',
  vms = '[data-label=VMs]',
  networks = '[data-label=Networks]',
  datastors = '[data-label=Name]',
  status = '[data-label=Status]',
}
